@@ -45,7 +45,7 @@ Puppet::Type.newtype(:murano_cfapi_paste_ini_config) do
     defaultto('<SERVICE DEFAULT>')
   end
 
-  autorequire(:package) do
-    'murano-common'
+  autorequire(:anchor) do
+    ['murano::install::end']
   end
 end
