@@ -25,7 +25,7 @@ describe 'murano::client' do
       end
 
       let :platform_params do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :pythonclient_package_name => 'python3-muranoclient' }
         when 'RedHat'
