@@ -27,9 +27,7 @@ describe 'murano::db::sync_cfapi' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({
-          :concat_basedir => '/var/lib/puppet/concat'
-        }))
+        facts.merge(OSDefaults.get_facts())
       end
 
       it_configures 'murano-dbsync-cfapi'
